@@ -203,14 +203,12 @@ class object(univention.admin.handlers.simpleLdap):
 			except univention.admin.uexceptions.noLock:
 				raise univention.admin.uexceptions.uidAlreadyUsed(self['username'])
 
-	def _ldap_pre_modify(self):
-		if self.hasChanged('username'):
-			username = self['username']
-			try:
-				newdn = u'uid=%s,%s' % (ldap.dn.escape_dn_chars(username), self.lo.parentDn(self.dn))
-				self._move(newdn)
-			finally:
-				univention.admin.allocators.release(self.lo, self.position, 'uid', username)
+	def _ldap_pre_rename(self, newdn):
+		super(object, self)._ldap_pre_rename(newdn)
+		try:
+			self.move(newdn)
+		finally:
+			univention.admin.allocators.release(self.lo, self.position, 'uid', self['username'])
 
 	def _ldap_modlist(self):
 		ml = univention.admin.handlers.simpleLdap._ldap_modlist(self)
@@ -302,7 +300,7 @@ class object(univention.admin.handlers.simpleLdap):
 			pwdCheck = univention.password.Check(self.lo)
 			pwdCheck.enableQualityCheck = True
 			try:
-				pwdCheck.check(self['password'], username=self['username'], displayname=self['displayName'])
+				pwdCheck.check(self['password'], username=self['username'])
 			except univention.password.CheckFailed as exc:
 				raise univention.admin.uexceptions.pwQuality(str(exc))
 
