@@ -279,7 +279,7 @@ property_descriptions = {
 	),
 	'e-mail': univention.admin.property(
 		short_description=_('E-mail address'),
-		long_description='',
+		long_description=_('This e-mail address serves only as contact information. This address has no effect on the UCS mail stack and is not related to a local mailbox.'),
 		syntax=univention.admin.syntax.emailAddress,
 		multivalue=True,
 	),
@@ -465,15 +465,15 @@ property_descriptions = {
 		copyable=True,
 	),
 	'mailPrimaryAddress': univention.admin.property(
-		short_description=_('Primary e-mail address'),
-		long_description='',
+		short_description=_('Primary e-mail address (mailbox)'),
+		long_description=_('E-mail address that will be used to create the IMAP/POP3 mailbox and that can be used as login for SMTP/IMAP/POP3 connections. The domain must be one of the UCS hosted e-mail domains.'),
 		syntax=univention.admin.syntax.primaryEmailAddressValidDomain,
 		include_in_default_search=True,
 		readonly_when_synced=True,
 	),
 	'mailAlternativeAddress': univention.admin.property(
-		short_description=_('Alternative e-mail address'),
-		long_description='',
+		short_description=_('E-mail alias address'),
+		long_description=_('Additional e-mail addresses for which e-mails will be delivered to the "Primary e-mail address". The domain must be one of the UCS hosted e-mail domains.'),
 		syntax=univention.admin.syntax.emailAddressValidDomain,
 		multivalue=True,
 		copyable=True,
@@ -1162,10 +1162,10 @@ def unmapKeyAndValue(old, encoding=()):
 	return [entry.decode(*encoding).split(u'=', 1) for entry in old]
 
 
-def mapWindowsFiletime(old):
+def mapWindowsFiletime(old, encoding=()):  # type: (str) -> List[bytes]
 	if old:
 		if old == "0":
-			return [old]
+			return [old.encode(*encoding)]
 		unixtime = time.strptime(old, '%Y%m%d%H%M%SZ')
 		d = long(116444736000000000)  # difference between 1601 and 1970
 		windows_filetime = long(calendar.timegm(unixtime)) * 10000000 + d
@@ -1173,18 +1173,19 @@ def mapWindowsFiletime(old):
 	return []
 
 
-def unmapWindowsFiletime(old):
+def unmapWindowsFiletime(old, encoding=()):  # type: (List[bytes]) -> str
 	if old and old[0]:
-		if old[0] == "0":
-			return old[0]
+		password_time = int(old[0].decode(*encoding))
+		if password_time == 0:
+			return u'%d' % (password_time,)
 		d = long(116444736000000000)  # difference between 1601 and 1970
-		unixtime = (int(old[0]) - d) / 10000000
+		unixtime = (password_time - d) // 10000000
 		try:
 			return time.strftime('%Y%m%d%H%M%SZ', time.gmtime(unixtime))
 		except ValueError:
-			#already unixtime, happens in environments with Samba3
-			ud.debug(ud.ADMIN, ud.INFO, 'Value of sambaBadPasswordTime is not set to a Windows Filetime (100 nanoseconds since January 1, 1601.)\nInstead its set to %s' % old[0])
-			return time.strftime('%Y%m%d%H%M%SZ', time.gmtime(int(old[0])))
+			# already unixtime, happens in environments with Samba3
+			ud.debug(ud.ADMIN, ud.INFO, 'Value of sambaBadPasswordTime is not set to a Windows Filetime (100 nanoseconds since January 1, 1601.)\nInstead its set to %s' % (password_time,))
+			return time.strftime('%Y%m%d%H%M%SZ', time.gmtime(password_time))
 	return u''
 
 
@@ -1660,7 +1661,15 @@ class object(univention.admin.handlers.simpleLdap):
 		self.__update_groups()
 		self.__primary_group()
 
+	def _ldap_pre_rename(self, newdn):
+		super(object, self)._ldap_pre_rename(newdn)
+		try:
+			self.move(newdn)
+		finally:
+			univention.admin.allocators.release(self.lo, self.position, 'uid', self['username'])
+
 	def _ldap_pre_modify(self):
+		super(object, self)._ldap_pre_modify()
 		if not self.oldattr.get('mailForwardCopyToSelf') and self['mailForwardCopyToSelf'] == '0' and not self['mailForwardAddress']:
 			self['mailForwardCopyToSelf'] = None
 
@@ -1668,14 +1677,6 @@ class object(univention.admin.handlers.simpleLdap):
 			if self['mailPrimaryAddress']:
 				self['mailPrimaryAddress'] = self['mailPrimaryAddress'].lower()
 
-		if self.hasChanged('username'):
-			username = self['username']
-			try:
-				newdn = u'uid=%s,%s' % (ldap.dn.escape_dn_chars(username), self.lo.parentDn(self.dn))
-				self._move(newdn)
-			finally:
-				univention.admin.allocators.release(self.lo, self.position, 'uid', username)
-
 		if self.hasChanged("uidNumber"):
 			# this should never happen, as uidNumber is marked as unchangeable
 			self._check_uid_gid_uniqueness()
